==> amity-sdk-7.5.1-alpha02-sources.jar: main/com/amity/socialcloud/sdk/social/data/community/CommunityJoinRequestLocalDataStore.kt <==
package com.amity.socialcloud.sdk.social.data.community

import androidx.paging.PagingSource
import com.amity.socialcloud.sdk.api.social.community.query.AmityCommunitySortOption
import com.amity.socialcloud.sdk.entity.comunity.JoinRequestEntity
import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.social.community.AmityJoinRequestStatus
import com.ekoapp.ekosdk.internal.data.UserDatabase
import io.reactivex.rxjava3.core.Completable
import io.reactivex.rxjava3.core.Flowable

class CommunityJoinRequestLocalDataStore {

    fun observe(invitationId: String): Flowable<JoinRequestEntity> {
        return UserDatabase.get().communityJoinRequestDao()
            .observeJoinRequest(invitationId)
            .map {
                if (it == null) {
                    throw AmityException.create(
                        message = "item not found",
                        cause = null,
                        error = AmityError.ITEM_NOT_FOUND
                    )
                } else {
                    return@map it
                }
            }
    }

    fun saveJoinRequest(items: List<JoinRequestEntity>): Completable {
        return Completable.fromAction { UserDatabase.get().communityJoinRequestDao().save(items) }
    }

    fun updateJoinRequest(
        targetId: String,
        userId: String,
        status: AmityJoinRequestStatus,
    ): Completable {
        return Completable.fromAction {
            UserDatabase.get().communityJoinRequestDao()
                .updateJoinRequestByTargetIdAndUserId(
                    targetId = targetId,
                    userId = userId,
                    status = status.name
                )
        }
    }

    fun deleteJoinRequest(targetId: String, userId: String): Completable {
        return Completable.fromAction {
            UserDatabase.get().communityJoinRequestDao()
                .deleteJoinRequestByCommunityIdAndUserId(targetId, userId)
        }
    }

    fun getCommunityJoinRequestsPagingSource(
        communityId: String,
        status: String,
        sortBy: AmityCommunitySortOption? = null,
        targetType: String,
        type: String,
    ): PagingSource<Int, JoinRequestEntity> {
        return UserDatabase.get().communityJoinRequestPagingDao()
            .queryCommunityJoinRequests(communityId, status, sortBy, targetType, type)
    }

    fun getLatestJoinRequests(joinRequestIds: List<String>): Flowable<List<JoinRequestEntity>> {
        return UserDatabase.get().communityJoinRequestDao().observeByJoinRequestIds(joinRequestIds)
//            .map { entities ->
//                val orderById = joinRequestIds.withIndex().associate { it.value to it.index }
//                val sortedCommunities = entities.sortedBy { orderById[it.joinRequestId] }
//                sortedCommunities
//            }
    }


//    fun getMyJoinRequest(communityId: String): Single<JoinRequestEntity> {
//        return UserDatabase.get().communityJoinRequestDao().getByIdNow(communityId)
//            .map {
//                if (it == null) {
//                    throw AmityException.create(
//                        message = "item not found",
//                        cause = null,
//                        error = AmityError.ITEM_NOT_FOUND
//                    )
//                } else {
//                    return@map it
//                }
//            }
//    }
}

==> amity-sdk-7.9.0-alpha02-sources.jar: main/com/amity/socialcloud/sdk/social/data/community/CommunityJoinRequestLocalDataStore.kt <==
package com.amity.socialcloud.sdk.social.data.community

import androidx.paging.PagingSource
import com.amity.socialcloud.sdk.api.social.community.query.AmityCommunitySortOption
import com.amity.socialcloud.sdk.entity.comunity.JoinRequestEntity
import com.amity.socialcloud.sdk.model.core.error.AmityError
import com.amity.socialcloud.sdk.model.core.error.AmityException
import com.amity.socialcloud.sdk.model.social.community.AmityJoinRequestStatus
import com.ekoapp.ekosdk.internal.data.UserDatabase
import io.reactivex.rxjava3.core.Completable
import io.reactivex.rxjava3.core.Flowable
import io.reactivex.rxjava3.schedulers.Schedulers

class CommunityJoinRequestLocalDataStore {

    fun observe(joinRequestId: String): Flowable<JoinRequestEntity> {
        return UserDatabase.get().communityJoinRequestDao()
            .observeJoinRequest(joinRequestId)
            .map {
                if (it == null) {
                    throw AmityException.create(
                        message = "item not found",
                        cause = null,
                        error = AmityError.ITEM_NOT_FOUND
                    )
                } else {
                    return@map it
                }
            }
    }

    fun getJoinRequestByTargetId(targetId: String): List<JoinRequestEntity>? {
        var joinRequest: List<JoinRequestEntity>? = null
        Completable.fromCallable {
            val entity = UserDatabase.get().communityJoinRequestDao().getJoinRequestsByTargetId(targetId)
            if (entity.isNotEmpty()) {
                joinRequest = entity
            }
        }.subscribeOn(Schedulers.io())
            .blockingAwait()
        return joinRequest
    }

    fun saveJoinRequest(items: List<JoinRequestEntity>): Completable {
        return Completable.fromAction { UserDatabase.get().communityJoinRequestDao().save(items) }
    }

    fun updateJoinRequest(
        targetId: String,
        userId: String,
        status: AmityJoinRequestStatus,
    ): Completable {
        return Completable.fromAction {
            UserDatabase.get().communityJoinRequestDao()
                .updateJoinRequestByTargetIdAndUserId(
                    targetId = targetId,
                    userId = userId,
                    status = status.status
                )
        }
    }

    fun deleteJoinRequest(targetId: String, userId: String): Completable {
        return Completable.fromAction {
            UserDatabase.get().communityJoinRequestDao()
                .deleteJoinRequestByCommunityIdAndUserId(targetId, userId)
        }
    }

    fun getCommunityJoinRequestsPagingSource(
        communityId: String,
        status: String,
        sortBy: AmityCommunitySortOption? = null,
        targetType: String,
        type: String,
    ): PagingSource<Int, JoinRequestEntity> {
        return UserDatabase.get().communityJoinRequestPagingDao()
            .queryCommunityJoinRequests(communityId, status, sortBy, targetType, type)
    }

    fun getJoinRequestList(joinRequestIds: List<String>): Flowable<List<JoinRequestEntity>> {
        return UserDatabase.get().communityJoinRequestDao().observeByJoinRequestIds(joinRequestIds)
    }


//    fun getMyJoinRequest(communityId: String): Single<JoinRequestEntity> {
//        return UserDatabase.get().communityJoinRequestDao().getByIdNow(communityId)
//            .map {
//                if (it == null) {
//                    throw AmityException.create(
//                        message = "item not found",
//                        cause = null,
//                        error = AmityError.ITEM_NOT_FOUND
//                    )
//                } else {
//                    return@map it
//                }
//            }
//    }
}
